# 贡献者契约行为准则

## 我们的承诺

为了营造一个开放而热情的环境，作为贡献者和维护者，我们承诺让每个人都能参与我们的项目和社区，无论年龄、体型、残疾、种族、性别认同和表达、经验水平、教育、社会经济地位、国籍、个人外貌、种族、宗教或性认同和取向如何，都不受骚扰。

## 我们的标准

有助于营造积极环境的行为示例包括：

* 使用欢迎和包容的语言
* 尊重不同的观点和经验
* 优雅地接受建设性的批评
* 关注对社区最有利的事情
* 对其他社区成员表示同情

参与者不可接受的行为示例包括：

* 使用性感语言或图像以及不受欢迎的性关注或挑逗
* 恶意挑逗、侮辱/贬损评论和人身或政治攻击
* 公开或私下骚扰
* 未经明确许可发布他人的私人信息，例如物理或电子地址
* 在专业环境中可能被合理视为不适当的其他行为

## 我们的责任

项目维护者负责澄清可接受行为的标准，并有望针对任何不可接受的行为采取适当和公平的纠正措施。

项目维护者有权利和责任删除、编辑或

拒绝不符合本行为准则的评论、提交、代码、wiki 编辑、问题和其他贡献，或暂时或永久禁止任何贡献者做出他们认为不适当、威胁、冒犯或有害的其他行为。

## 范围

当个人代表项目或其社区时，本行为准则既适用于项目空间内，也适用于公共空间。代表项目或社区的示例包括使用官方项目电子邮件地址、通过官方社交媒体帐户发帖或在线上或线下活动中担任指定代表。项目维护者可以进一步定义和澄清项目的代表。

## 执行

可以通过联系项目团队的邮件地址 contact@meloland.org 报告辱骂、骚扰或其他不可接受的行为。所有投诉都将接受审查和调查，并将根据情况做出必要且适当的回应。项目团队有义务对事件报告者保密。具体执行政策的更多细节可能会单独发布。不遵守或不真诚执行行为准则的项目维护者可能会面临由项目领导层其他成员决定的暂时或永久的后果。

## 归属

本行为准则改编自 [贡献者契约][homepage]，版本 1.4，可在 https://www.contributor-covenant.org/version/1/4/code-of-conduct.html 获取

[homepage]: https://www.contributor-covenant.org

# Contributor Covenant Code of Conduct

## Our Pledge

In the interest of fostering an open and welcoming environment, we as
contributors and maintainers pledge to making participation in our project and
our community a harassment-free experience for everyone, regardless of age, body
size, disability, ethnicity, gender identity and expression, level of experience,
education, socio-economic status, nationality, personal appearance, race,
religion, or sexual identity and orientation.

## Our Standards

Examples of behavior that contributes to creating a positive environment
include:

* Using welcoming and inclusive language
* Being respectful of differing viewpoints and experiences
* Gracefully accepting constructive criticism
* Focusing on what is best for the community
* Showing empathy towards other community members

Examples of unacceptable behavior by participants include:

* The use of sexualized language or imagery and unwelcome sexual attention or
  advances
* Trolling, insulting/derogatory comments, and personal or political attacks
* Public or private harassment
* Publishing others' private information, such as a physical or electronic
  address, without explicit permission
* Other conduct which could reasonably be considered inappropriate in a
  professional setting

## Our Responsibilities

Project maintainers are responsible for clarifying the standards of acceptable
behavior and are expected to take appropriate and fair corrective action in
response to any instances of unacceptable behavior.

Project maintainers have the right and responsibility to remove, edit, or
reject comments, commits, code, wiki edits, issues, and other contributions
that are not aligned to this Code of Conduct, or to ban temporarily or
permanently any contributor for other behaviors that they deem inappropriate,
threatening, offensive, or harmful.

## Scope

This Code of Conduct applies both within project spaces and in public spaces
when an individual is representing the project or its community. Examples of
representing a project or community include using an official project e-mail
address, posting via an official social media account, or acting as an appointed
representative at an online or offline event. Representation of a project may be
further defined and clarified by project maintainers.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported by contacting the project team at contact@meloland.org. All
complaints will be reviewed and investigated and will result in a response that
is deemed necessary and appropriate to the circumstances. The project team is
obligated to maintain confidentiality with regard to the reporter of an incident.
Further details of specific enforcement policies may be posted separately.

Project maintainers who do not follow or enforce the Code of Conduct in good
faith may face temporary or permanent repercussions as determined by other
members of the project's leadership.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 1.4,
available at https://www.contributor-covenant.org/version/1/4/code-of-conduct.html
